<?php

/*
 * This file is part of WordPress Boilerplate.
 *
 * (c) Vincent Klaiber <hello@vinkla.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

if (!function_exists('config')) {

    /**
     * Get the specified configuration value.
     *
     * @param array|string $key
     * @param mixed $default
     *
     * @return mixed
     */
    function config($key = null, $default = null)
    {
        $config = [];

        foreach (glob(get_template_directory().'/config/*.php') as $file) {
            $config[basename($file, '.php')] = require $file;
        }

        if (is_null($key)) {
            return $config;
        }

        if (isset($config[$key])) {
            return $config[$key];
        }

        foreach (explode('.', $key) as $segment) {
            if (!is_array($config) || !array_key_exists($segment, $config)) {
                return $default;
            }

            $config = $config[$segment];
        }

        return $config;
    }
}
